Transformers
------------

Specialized transformers to address Gordo specific problems.
This function just like Scikit-Learn's transformers and thus can be
inserted into ``Pipeline`` objects.

Imputers
========

.. automodule:: gordo.machine.model.transformers.imputer
    :members:
    :undoc-members:
    :show-inheritance:
